==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/CellActionManagerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var CellActionManagerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CellActionManagerDescriptionMetadata, _super);
    function CellActionManagerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CellActionManagerDescriptionMetadata.b = function (a) {
        if (CellActionManagerDescriptionMetadata.a == null) {
            CellActionManagerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CellActionManagerDescriptionMetadata.c(CellActionManagerDescriptionMetadata.a);
        }
        if (a.k(CellActionManagerDescriptionMetadata.a)) {
            return;
        }
        a.ab(CellActionManagerDescriptionMetadata.a);
    };
    CellActionManagerDescriptionMetadata.c = function (a) {
        a.item("IsControlPressed", "Boolean");
        a.item("IsShiftPressed", "Boolean");
    };
    CellActionManagerDescriptionMetadata.d = function (a) {
        CellActionManagerDescriptionMetadata.b(a);
        a.ac("CellActionManager", CellActionManagerDescriptionMetadata.a);
    };
    CellActionManagerDescriptionMetadata.$t = markType(CellActionManagerDescriptionMetadata, 'CellActionManagerDescriptionMetadata');
    CellActionManagerDescriptionMetadata.a = null;
    return CellActionManagerDescriptionMetadata;
}(Base));
export { CellActionManagerDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/CellActionManagerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var CellActionManagerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CellActionManagerDescriptionMetadata, _super);
    function CellActionManagerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CellActionManagerDescriptionMetadata.b = function (a) {
        if (CellActionManagerDescriptionMetadata.a == null) {
            CellActionManagerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CellActionManagerDescriptionMetadata.c(CellActionManagerDescriptionMetadata.a);
        }
        if (a.k(CellActionManagerDescriptionMetadata.a)) {
            return;
        }
        a.ac(CellActionManagerDescriptionMetadata.a);
    };
    CellActionManagerDescriptionMetadata.c = function (a) {
        a.item("IsControlPressed", "Boolean");
        a.item("IsShiftPressed", "Boolean");
    };
    CellActionManagerDescriptionMetadata.d = function (a) {
        CellActionManagerDescriptionMetadata.b(a);
        a.ad("CellActionManager", CellActionManagerDescriptionMetadata.a);
    };
    CellActionManagerDescriptionMetadata.$t = markType(CellActionManagerDescriptionMetadata, 'CellActionManagerDescriptionMetadata');
    CellActionManagerDescriptionMetadata.a = null;
    return CellActionManagerDescriptionMetadata;
}(Base));
export { CellActionManagerDescriptionMetadata };
